Documentation
¶
Index ¶
Constants ¶
const ErrBadRequestCode = "PIT-400"
ErrBadRequestCode is a string code representing a bad request related error
const ErrClientClosedRequest = "PIT-499"
ErrClientClosedRequest is a string code representing the client closed request error
const ErrClosedRequest = "PIT-498"
ErrClosedRequest is a string code representing the closed request error
const ErrInternalCode = "PIT-500"
ErrInternalCode is a string code representing an internal Pitaya error
const ErrNotFoundCode = "PIT-404"
ErrNotFoundCode is a string code representing a not found related error
const ErrRequestTimeout = "PIT-408"
ErrRequestTimeout is a string code representing the request timeout error
const ErrUnknownCode = "PIT-000"
ErrUnknownCode is a string code representing an unknown error This will be used when no error code is sent by the handler
Variables ¶
This section is empty.
Functions ¶
func CodeFromError ¶
CodeFromError returns the code of error. If error is nil, return empty string. If error is not a pitaya error, returns unkown code